# verilog.pm (HCT::lang::hdl::verilog)
#
# Copyright 2008, 2009
# Slade Maurer
#
# This file is part of HCT, the Hardware Complexity Tool
#
# HCT is free software: you can redistribute it and/or modify
# it under the terms of the GNU Lesser General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
# 
# HCT is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU Lesser General Public License
# along with HCT.  If not, see <http://www.gnu.org/licenses/>.

=head1 NAME

HCT::lang::hdl::verilog - Class of Verilog language. 

=head1 DESCRIPTION

Verilog is a hardware description language (HDL) used to model 
electronic systems. Verilog HDL, not to be confused with VHDL, is most commonly 
used in the design, verification, and implementation of digital logic chips 
at the Register transfer level (RTL) level of abstraction. It is also 
used in the verification of analog and mixed-signal circuits.

=head1 VERILOG SYNTAX

A description of the syntax in Backus-Naur form 
(predates the IEEE-1364 standard): L<http://www.verilog.com/VerilogBNF.html>. Also 
a heavily linked BNF syntax for Verilog 2001 can be found here 
L<http://www.externsoft.ch/download/verilog.html>.

=cut

package HCT::lang::hdl::verilog;

# Use base object for creating a new language.
use base 'HCT::Lang::LangDriver';

use strict;
use warnings;

require HCT::lang::hdl::verilog::lexer;
require HCT::lang::hdl::verilog::parser;

our @FILE_ASSOCIATIONS = ('v');

our %OUTPUT_METRICS = ('MCCABE',0,'IO',0,'NET',0,'TIME',0,'SLOC',0,'COMMENT_LINES',0);
our %OUTPUT_LEVELS = (
	'TERMINAL' => [
		[  0 , undef],
		[ 72 , [[4,'IO'],[5,'NET'],[8,'MCCABE'],[6,'TIME']] ],
		[ 72 , [[6,'SLOC'],[15,'COMMENT_LINES'],[6,'TIME']]],
	],
	'CSV' => [
		[  0 , undef],
		[ 99 , [[4,'IO'],[5,'NET'],[8,'MCCABE'],[6,'SLOC'],[15,'COMMENT_LINES'],[6,'TIME']] ],	
	],
);

sub new
{
	my $class = shift;
	my $self = $class->SUPER::new (@_);

	$self->parser (new HCT::lang::hdl::verilog::parser);
	$self->lexer (new HCT::lang::hdl::verilog::lexer);

	$self->output->metrics (\%OUTPUT_METRICS);
	$self->output->levels (\%OUTPUT_LEVELS);

	return $self;
}

1;
